@@ -1,3 +1,20 @@
+/*
+ * pi-syspkt.h
+ *
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Library General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
 #ifndef _PILOT_SYSPKT_H
 #define _PILOT_SYSPKT_H
 
@@ -38,7 +55,7 @@ extern "C" {
 
 	struct RPC_param {
 		int byRef;
-		int size;
+		size_t size;
 		int invert;
 		int arg;
 		void *data;
@@ -51,8 +68,6 @@ extern "C" {
 		struct RPC_param param[20];
 	};
 
-	extern int sys_RPCerror;
-
 	extern int sys_UnpackState
 	    PI_ARGS((void *buffer, struct Pilot_state * s));
 
@@ -82,7 +97,7 @@ extern "C" {
 	    PI_ARGS((int sd, struct Pilot_breakpoint * b));
 	extern int sys_Find
 	    PI_ARGS((int sd, unsigned long startaddr,
-		     unsigned long stopaddr, int len, int caseinsensitive,
+		     unsigned long stopaddr, size_t len, int caseinsensitive,
 		     void *data, unsigned long *found));
 
 	extern int sys_RemoteEvent
@@ -90,7 +105,7 @@ extern "C" {
 		     int keymod, int keyasc, int keycode));
 
 	extern int sys_RPC
-	    PI_ARGS((int sd, int socket, int trap, long *D0, long *A0,
+	    PI_ARGS((int sd, int sock, int trap, long *D0, long *A0,
 		     int params, struct RPC_param * param, int rep));
 
 #define RPC_Byte(data) (-2),((unsigned int)htons((data)<<8))
@@ -111,7 +126,7 @@ extern "C" {
 #define RPC_NoReply 0
 
 	extern int RPC
-	    PI_ARGS((int sd, int socket, int trap, int ret, ...));
+	    PI_ARGS((int sd, int sock, int trap, int ret, ...));
 
 	extern void InvertRPC PI_ARGS((struct RPC_params * p));
 	extern void UninvertRPC PI_ARGS((struct RPC_params * p));
@@ -120,7 +135,7 @@ extern "C" {
 	    PI_ARGS((struct RPC_params * p, int trap, int reply, ...));
 
 	extern unsigned long DoRPC
-	    PI_ARGS((int sd, int socket, struct RPC_params * p,
+	    PI_ARGS((int sd, int sock, struct RPC_params * p,
 		     int *error));
 
 	extern int dlp_ProcessRPC
