@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -24,30 +24,23 @@
 #include <config.h>
 #endif
 
-#ifdef WIN32
-#include <winsock.h>
-#else
 #include <sys/types.h>
+#include <sys/socket.h>
 #include <netinet/in.h>
-#endif
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
 #include <string.h>
 
 #include "pi-source.h"
-#include "pi-socket.h"
 #include "pi-syspkt.h"
 #include "pi-slp.h"
 #include "pi-serial.h"
+#include "pi-error.h"
 
 /* Declare prototypes */
-int sys_RPCerror;
-int sys_PackRegisters(void *data, struct Pilot_registers *r);
-int RPC_MemCardInfo(int sd, int cardno, char * cardname, char * manufname,
-                    int * version, long * date, long * romsize, long * ramsize,
-                    long * freeram);
+static int sys_PackRegisters(void *data, struct Pilot_registers *r);
+
 
 /***********************************************************************
  *
@@ -60,7 +53,8 @@ int RPC_MemCardInfo(int sd, int cardno, char * cardname, char * manufname,
  * Returns:     Nothing
  *
  ***********************************************************************/
-int sys_UnpackState(void *buffer, struct Pilot_state *s)
+int
+sys_UnpackState(void *buffer, struct Pilot_state *s)
 {
 	int 	idx;
 	unsigned char *data = buffer;
@@ -84,6 +78,7 @@ int sys_UnpackState(void *buffer, struct Pilot_state *s)
 	return 0;
 }
 
+
 /***********************************************************************
  *
  * Function:    sys_UnpackRegisters
@@ -95,7 +90,8 @@ int sys_UnpackState(void *buffer, struct Pilot_state *s)
  * Returns:     0
  *
  ***********************************************************************/
-int sys_UnpackRegisters(void *data, struct Pilot_registers *r)
+int
+sys_UnpackRegisters(void *data, struct Pilot_registers *r)
 {
 	unsigned char *buffer = data;
 
@@ -123,6 +119,7 @@ int sys_UnpackRegisters(void *data, struct Pilot_registers *r)
 	return 0;
 }
 
+
 /***********************************************************************
  *
  * Function:    sys_PackRegisters
@@ -134,7 +131,8 @@ int sys_UnpackRegisters(void *data, struct Pilot_registers *r)
  * Returns:     0
  *
  ***********************************************************************/
-int sys_PackRegisters(void *data, struct Pilot_registers *r)
+static int
+sys_PackRegisters(void *data, struct Pilot_registers *r)
 {
 	int 	idx;
 	unsigned char *buffer = data;
@@ -163,7 +161,8 @@ int sys_PackRegisters(void *data, struct Pilot_registers *r)
  * Returns:     Nothing
  *
  ***********************************************************************/
-int sys_Continue(int sd, struct Pilot_registers *r, struct Pilot_watch *w)
+int
+sys_Continue(int sd, struct Pilot_registers *r, struct Pilot_watch *w)
 {
 	char 	buf[94];
 
@@ -198,7 +197,8 @@ int sys_Continue(int sd, struct Pilot_registers *r, struct Pilot_watch *w)
  * Returns:     Socket, command, 6 bytes
  *
  ***********************************************************************/
-int sys_Step(int sd)
+int
+sys_Step(int sd)
 {
 	char 	buf[94];
 
@@ -223,32 +223,42 @@ int sys_Step(int sd)
  * Returns:     Nothing
  *
  ***********************************************************************/
-int sys_SetBreakpoints(int sd, struct Pilot_breakpoint *b)
+int
+sys_SetBreakpoints(int sd, struct Pilot_breakpoint *b)
 {
 	int 	idx;
-	char 	buf[94];
+	pi_buffer_t *buf;
 
-	buf[0] = 0;
-	buf[1] = 0;
-	buf[2] = 0;
-	buf[3] = 0;
-	buf[4] = 0x0c;
-	buf[5] = 0;		/* gapfill */
-
-	for (idx = 0; idx < 6; idx++) {
-		set_long(buf + 6 + idx * 6, b[idx].address);
-		set_byte(buf + 10 + idx * 6, b[idx].enabled);
-		set_byte(buf + 11 + idx * 6, 0);
+	buf = pi_buffer_new (94);
+	if (buf == NULL) {
+		errno = ENOMEM;
+		return pi_set_error(sd, PI_ERR_GENERIC_MEMORY);
 	}
 
-	pi_write(sd, buf, 42);
+	buf->data[0] = 0;
+	buf->data[1] = 0;
+	buf->data[2] = 0;
+	buf->data[3] = 0;
+	buf->data[4] = 0x0c;
+	buf->data[5] = 0;		/* gapfill */
+
+	for (idx = 0; idx < 6; idx++) {
+		set_long(buf->data + 6 + idx * 6, b[idx].address);
+		set_byte(buf->data + 10 + idx * 6, b[idx].enabled);
+		set_byte(buf->data + 11 + idx * 6, 0);
+	}
+
+	pi_write(sd, buf->data, 42);
 
 	idx = pi_read(sd, buf, 6);
 
-	if ((idx <= 0) || (buf[4] != (char) 0x8c))
+	if (idx <= 0 || buf->data[4] != (unsigned char) 0x8c) {
+		pi_buffer_free (buf);
 		return 0;
-	else
-		return 1;
+	}
+
+	pi_buffer_free (buf);
+	return 1;
 }
 
 /***********************************************************************
@@ -262,30 +272,40 @@ int sys_SetBreakpoints(int sd, struct Pilot_breakpoint *b)
  * Returns:     Nothing
  *
  ***********************************************************************/
-int sys_SetTrapBreaks(int sd, int *traps)
+int
+sys_SetTrapBreaks(int sd, int *traps)
 {
 	int 	idx;
-	char 	buf[94];
+	pi_buffer_t *buf;
 
-	buf[0] = 0;
-	buf[1] = 0;
-	buf[2] = 0;
-	buf[3] = 0;
-	buf[4] = 0x11;
-	buf[5] = 0;		/* gapfill */
-
-	for (idx = 0; idx < 5; idx++) {
-		set_short(buf + 6 + idx * 2, traps[idx]);
+	buf = pi_buffer_new (32);
+	if (buf == NULL) {
+		errno = ENOMEM;
+		return pi_set_error(sd, PI_ERR_GENERIC_MEMORY);
 	}
 
-	pi_write(sd, buf, 16);
+	buf->data[0] = 0;
+	buf->data[1] = 0;
+	buf->data[2] = 0;
+	buf->data[3] = 0;
+	buf->data[4] = 0x11;
+	buf->data[5] = 0;		/* gapfill */
+
+	for (idx = 0; idx < 5; idx++) {
+		set_short(buf->data + 6 + idx * 2, traps[idx]);
+	}
+
+	pi_write(sd, buf->data, 16);
 
 	idx = pi_read(sd, buf, 6);
 
-	if ((idx <= 0) || (buf[4] != (char) 0x91))
+	if ((idx <= 0) || (buf->data[4] != (unsigned char) 0x91)) {
+		pi_buffer_free (buf);
 		return 0;
-	else
-		return 1;
+	}
+
+	pi_buffer_free (buf);
+	return 1;
 }
 
 /***********************************************************************
@@ -299,32 +319,43 @@ int sys_SetTrapBreaks(int sd, int *traps)
  * Returns:     Nothing
  *
  ***********************************************************************/
-int sys_GetTrapBreaks(int sd, int *traps)
+int
+sys_GetTrapBreaks(int sd, int *traps)
 {
 	int 	idx;
-	char 	buf[94];
+	pi_buffer_t *buf;
 
-	buf[0] = 0;
-	buf[1] = 0;
-	buf[2] = 0;
-	buf[3] = 0;
-	buf[4] = 0x10;
-	buf[5] = 0;		/* gapfill */
+	buf = pi_buffer_new (32);
+	if (buf == NULL) {
+		errno = ENOMEM;
+		return pi_set_error(sd, PI_ERR_GENERIC_MEMORY);
+	}
 
-	pi_write(sd, buf, 6);
+	buf->data[0] = 0;
+	buf->data[1] = 0;
+	buf->data[2] = 0;
+	buf->data[3] = 0;
+	buf->data[4] = 0x10;
+	buf->data[5] = 0;		/* gapfill */
+
+	pi_write(sd, buf->data, 6);
 
 	idx = pi_read(sd, buf, 16);
 
-	if ((idx < 16) || (buf[4] != (char) 0x90))
+	if ((idx < 16) || (buf->data[4] != (unsigned char) 0x90)) {
+		pi_buffer_free (buf);
 		return 0;
-
-	for (idx = 0; idx < 5; idx++) {
-		traps[idx] = get_short(buf + 6 + idx * 2);
 	}
 
+	for (idx = 0; idx < 5; idx++) {
+		traps[idx] = get_short(buf->data + 6 + idx * 2);
+	}
+
+	pi_buffer_free (buf);
 	return 1;
 }
 
+
 /***********************************************************************
  *
  * Function:    sys_ToggleDbgBreaks
@@ -336,28 +367,43 @@ int sys_GetTrapBreaks(int sd, int *traps)
  * Returns:     Nothing
  *
  ***********************************************************************/
-int sys_ToggleDbgBreaks(int sd)
+int
+sys_ToggleDbgBreaks(int sd)
 {
 	int 	idx;
-	char 	buf[94];
+	pi_buffer_t *buf;
+	unsigned char byte;
 
-	buf[0] = 0;
-	buf[1] = 0;
-	buf[2] = 0;
-	buf[3] = 0;
-	buf[4] = 0x0d;
-	buf[5] = 0;		/* gapfill */
+	buf = pi_buffer_new (32);
+	if (buf == NULL) {
+		errno = ENOMEM;
+		return pi_set_error(sd, PI_ERR_GENERIC_MEMORY);
+	}
 
-	pi_write(sd, buf, 6);
+	buf->data[0] = 0;
+	buf->data[1] = 0;
+	buf->data[2] = 0;
+	buf->data[3] = 0;
+	buf->data[4] = 0x0d;
+	buf->data[5] = 0;		/* gapfill */
+
+	pi_write(sd, buf->data, 6);
 
 	idx = pi_read(sd, buf, 7);
 
-	if ((idx < 7) || (buf[4] != (char) 0x8d))
+	if ((idx < 7) || (buf->data[4] != (unsigned char) 0x8d)) {
+		pi_buffer_free (buf);
 		return 0;
+	}
 
-	return get_byte(buf + 6);
+	byte = get_byte(buf->data + 6);
+
+	pi_buffer_free (buf);
+
+	return byte;
 }
 
+
 /***********************************************************************
  *
  * Function:    sys_QueryState
@@ -369,7 +415,8 @@ int sys_ToggleDbgBreaks(int sd)
  * Returns:     Nothing
  *
  ***********************************************************************/
-int sys_QueryState(int sd)
+int
+sys_QueryState(int sd)
 {
 	char 	buf[6];
 
@@ -398,8 +445,14 @@ int
 sys_ReadMemory(int sd, unsigned long addr, unsigned long len, void *dest)
 {
 	int 	result;
-	unsigned char buf[0xffff];
 	unsigned long todo, done;
+	pi_buffer_t *buf;
+
+	buf = pi_buffer_new (0xFFFF);
+	if (buf == NULL) {
+		errno = ENOMEM;
+		return pi_set_error(sd, PI_ERR_GENERIC_MEMORY);
+	}
 
 	done = 0;
 	do {
@@ -407,39 +460,45 @@ sys_ReadMemory(int sd, unsigned long addr, unsigned long len, void *dest)
 		if (todo > 256)
 			todo = 256;
 
-		buf[0] = 0;
-		buf[1] = 0;
-		buf[2] = 0;
-		buf[3] = 0;
-		buf[4] = 0x01;
-		buf[5] = 0;	/* gapfill */
+		buf->data[0] = 0;
+		buf->data[1] = 0;
+		buf->data[2] = 0;
+		buf->data[3] = 0;
+		buf->data[4] = 0x01;
+		buf->data[5] = 0;	/* gapfill */
 
-		set_long(buf + 6, addr + done);
-		set_short(buf + 10, todo);
+		set_long(buf->data + 6, addr + done);
+		set_short(buf->data + 10, todo);
 
-		pi_write(sd, buf, 12);
+		pi_write(sd, buf->data, 12);
 
 		result = pi_read(sd, buf, todo + 6);
 
-		if (result < 0)
+		if (result < 0) {
+			pi_buffer_free (buf);
 			return done;
+		}
 
-		if ((buf[4] == 0x81)
+		if ((buf->data[4] == 0x81)
 		    && ((unsigned int) result == todo + 6)) {
-			memcpy(((char *) dest) + done, buf + 6, todo);
+			memcpy(((char *) dest) + done, buf->data + 6, todo);
 			done += todo;
 		} else {
+			pi_buffer_free (buf);
 			return done;
 		}
 	} while (done < len);
+
+	pi_buffer_free (buf);
 	return done;
 }
 
+
 /***********************************************************************
  *
  * Function:    sys_WriteMemory
  *
- * Summary:     Write memory (0x02, 0x82) 
+ * Summary:     Write memory (0x02, 0x82)
  *
  * Parameters:  None
  *
@@ -450,8 +509,14 @@ int
 sys_WriteMemory(int sd, unsigned long addr, unsigned long len, void *src)
 {
 	int 	result;
-	unsigned char buf[0xffff];
 	unsigned long todo, done;
+	pi_buffer_t *buf;
+
+	buf = pi_buffer_new (0xFFFF);
+	if (buf == NULL) {
+		errno = ENOMEM;
+		return pi_set_error(sd, PI_ERR_GENERIC_MEMORY);
+	}
 
 	done = 0;
 	do {
@@ -459,34 +524,40 @@ sys_WriteMemory(int sd, unsigned long addr, unsigned long len, void *src)
 		if (todo > 256)
 			todo = 256;
 
-		buf[0] = 0;
-		buf[1] = 0;
-		buf[2] = 0;
-		buf[3] = 0;
-		buf[4] = 0x02;
-		buf[5] = 0;	/* gapfill */
+		buf->data[0] = 0;
+		buf->data[1] = 0;
+		buf->data[2] = 0;
+		buf->data[3] = 0;
+		buf->data[4] = 0x02;
+		buf->data[5] = 0;	/* gapfill */
 
-		set_long(buf + 6, addr);
-		set_short(buf + 10, len);
-		memcpy(buf + 12, ((char *) src) + done, todo);
+		set_long(buf->data + 6, addr);
+		set_short(buf->data + 10, len);
+		memcpy(buf->data + 12, (char *)src + done, todo);
 
-		pi_write(sd, buf, len + 12);
+		pi_write(sd, buf->data, len + 12);
 
 		result = pi_read(sd, buf, 6);
 
-		if (result < 0)
+		if (result < 0) {
+			pi_buffer_free (buf);
 			return done;
+		}
 
-		if ((buf[4] == 0x82)
-		    && ((unsigned int) result == todo + 6)) {
+		if ((buf->data[4] == (unsigned char)0x82)
+		    && ((unsigned long) result == todo + 6)) {
 			;
 		} else {
+			pi_buffer_free (buf);
 			return done;
 		}
 	} while (done < len);
+
+	pi_buffer_free (buf);
 	return done;
 }
 
+
 /***********************************************************************
  *
  * Function:    sys_Find
@@ -499,43 +570,57 @@ sys_WriteMemory(int sd, unsigned long addr, unsigned long len, void *src)
  *
  ***********************************************************************/
 int
-sys_Find(int sd, unsigned long startaddr, unsigned long stopaddr, int len,
+sys_Find(int sd, unsigned long startaddr, unsigned long stopaddr, size_t len,
 	 int caseinsensitive, void *data, unsigned long *found)
 {
 	int 	result;
-	unsigned char buf[0xffff];
+	unsigned char byte;
+	pi_buffer_t *buf;
 
-	buf[0] = 0;
-	buf[1] = 0;
-	buf[2] = 0;
-	buf[3] = 0;
-	buf[4] = 0x11;
-	buf[5] = 0;		/* gapfill */
+	buf = pi_buffer_new (len + 17);
+	if (buf == NULL) {
+		errno = ENOMEM;
+		return pi_set_error(sd, PI_ERR_GENERIC_MEMORY);
+	}
 
-	set_long(buf + 6, startaddr);
-	set_long(buf + 10, stopaddr);
-	set_short(buf + 14, len);
-	set_byte(buf + 16, caseinsensitive);
-	memcpy(buf + 17, data, len);
+	buf->data[0] = 0;
+	buf->data[1] = 0;
+	buf->data[2] = 0;
+	buf->data[3] = 0;
+	buf->data[4] = 0x11;
+	buf->data[5] = 0;		/* gapfill */
 
-	pi_write(sd, buf, len + 17);
+	set_long(buf->data + 6, startaddr);
+	set_long(buf->data + 10, stopaddr);
+	set_short(buf->data + 14, len);
+	set_byte(buf->data + 16, caseinsensitive);
+	memcpy(buf->data + 17, data, len);
+
+	pi_write(sd, buf->data, len + 17);
 
 	result = pi_read(sd, buf, 12);
 
-	if (result < 0)
+	if (result < 0) {
+		pi_buffer_free (buf);
 		return result;
+	}
 
 	if (found)
-		*found = get_long(buf + 6);
+		*found = get_long(buf->data + 6);
 
-	return get_byte(buf + 10);
+	byte = get_byte(buf->data + 10);
+
+	pi_buffer_free (buf);
+
+	return byte;
 }
 
+
 /***********************************************************************
  *
  * Function:    sys_RemoteEvent
  *
- * Summary:     Parameters sent from host to target to feed pen and 
+ * Summary:     Parameters sent from host to target to feed pen and
  *		keyboard events. They do not require a response.
  *
  * Parameters:  None
@@ -565,6 +650,7 @@ sys_RemoteEvent(int sd, int penDown, int x, int y, int keypressed,
 	return pi_write(sd, buf, 16);
 }
 
+
 /***********************************************************************
  *
  * Function:    sys_RPC
@@ -577,25 +663,31 @@ sys_RemoteEvent(int sd, int penDown, int x, int y, int keypressed,
  *
  ***********************************************************************/
 int
-sys_RPC(int sd, int socket, int trap, long *D0, long *A0, int params,
+sys_RPC(int sd, int sockaddr, int trap, long *D0, long *A0, int params,
 	struct RPC_param *param, int reply)
 {
 	int 	idx;
-	unsigned char buf[4096];
 	unsigned char *c;
+	pi_buffer_t *buf;
 
-	buf[0] = socket;	/* 0 for debug, 1 for console */
-	buf[1] = socket;
-	buf[2] = 0;
-	buf[4] = 0x0a;
-	buf[5] = 0;
+	buf = pi_buffer_new (4096);
+	if (buf == NULL) {
+		errno = ENOMEM;
+		return pi_set_error(sd, PI_ERR_GENERIC_MEMORY);
+	}
 
-	set_short(buf + 6, trap);
-	set_long(buf + 8, *D0);
-	set_long(buf + 12, *A0);
-	set_short(buf + 16, params);
+	buf->data[0] = sockaddr;	/* 0 for debug, 1 for console */
+	buf->data[1] = sockaddr;
+	buf->data[2] = 0;
+	buf->data[4] = 0x0a;
+	buf->data[5] = 0;
 
-	c = buf + 18;
+	set_short(buf->data + 6, trap);
+	set_long(buf->data + 8, *D0);
+	set_long(buf->data + 12, *A0);
+	set_short(buf->data + 16, params);
+
+	c = buf->data + 18;
 	for (idx = params - 1; idx >= 0; idx--) {
 		set_byte(c, param[idx].byRef);
 		c++;
@@ -608,24 +700,27 @@ sys_RPC(int sd, int socket, int trap, long *D0, long *A0, int params,
 			*c++ = 0;
 	}
 
-	if (socket == 3)
-		set_short(buf + 4, c - buf - 6);
+	if (sockaddr == 3)
+		set_short(buf->data + 4, c - buf->data - 6);
 
-	pi_write(sd, buf + 4, c - buf - 4);
+	pi_write(sd, buf->data + 4,(size_t)(c - buf->data - 4));
 
 	if (reply) {
 		int l = pi_read(sd, buf, 4096);
 
-		if (l < 0)
+		if (l < 0) {
+			pi_buffer_free (buf);
 			return l;
-		if (l < 2)
-			return -1;
-		if (buf[0] != 0x8a)
-			return -2;
+		}
 
-		*D0 = get_long(buf + 4);
-		*A0 = get_long(buf + 8);
-		c = buf + 14;
+		if (buf->data[0] != (unsigned char)0x8a) {
+			pi_buffer_free (buf);
+			return pi_set_error(sd, -2);
+		}
+
+		*D0 = get_long(buf->data + 4);
+		*A0 = get_long(buf->data + 8);
+		c = buf->data + 14;
 		for (idx = params - 1; idx >= 0; idx--) {
 			if (param[idx].byRef && param[idx].data)
 				memcpy(param[idx].data, c + 2,
@@ -633,9 +728,12 @@ sys_RPC(int sd, int socket, int trap, long *D0, long *A0, int params,
 			c += 2 + ((get_byte(c + 1) + 1) & ~1);
 		}
 	}
+
+	pi_buffer_free (buf);
 	return 0;
 }
 
+
 /***********************************************************************
  *
  * Function:    RPC
@@ -647,7 +745,8 @@ sys_RPC(int sd, int socket, int trap, long *D0, long *A0, int params,
  * Returns:     Nothing
  *
  ***********************************************************************/
-int RPC(int sd, int socket, int trap, int reply, ...)
+int
+RPC(int sd, int sockaddr, int trap, int reply, ...)
 {
 	int 	idx 	= 0,
 		j,
@@ -682,7 +781,7 @@ int RPC(int sd, int socket, int trap, int reply, ...)
 				if (p[idx].size == 2) {
 					int *s = c;
 
-					*s = htons((short) *s);
+					*s = htons(*s);
 				} else {
 					int *l = c;
 
@@ -694,8 +793,8 @@ int RPC(int sd, int socket, int trap, int reply, ...)
 	}
 	va_end(ap);
 
-	sys_RPCerror =
-	    sys_RPC(sd, socket, trap, &D0, &A0, idx, p, reply != 2);
+	if (sys_RPC(sd, sockaddr, trap, &D0, &A0, idx, p, reply != 2) < 0)
+	    return pi_error(sd);
 
 	for (j = 0; j < idx; j++) {
 		if (p[j].invert) {
@@ -704,7 +803,7 @@ int RPC(int sd, int socket, int trap, int reply, ...)
 			if (p[j].size == 2) {
 				int *s = c;
 
-				*s = htons((short) *s);
+				*s = htons(*s);
 			} else {
 				int *l = c;
 
@@ -715,10 +814,10 @@ int RPC(int sd, int socket, int trap, int reply, ...)
 
 	if (reply)
 		return A0;
-	else
-		return D0;
+	return D0;
 }
 
+
 /***********************************************************************
  *
  * Function:    PackRPC
@@ -730,7 +829,8 @@ int RPC(int sd, int socket, int trap, int reply, ...)
  * Returns:     Nothing
  *
  ***********************************************************************/
-int PackRPC(struct RPC_params *p, int trap, int reply, ...)
+int
+PackRPC(struct RPC_params *p, int trap, int reply, ...)
 {
 	int 	idx = 0;
 	va_list ap;
@@ -767,18 +867,20 @@ int PackRPC(struct RPC_params *p, int trap, int reply, ...)
 	return 0;
 }
 
+
 /***********************************************************************
  *
  * Function:    UninvertRPC
  *
- * Summary:     
+ * Summary:
  *
  * Parameters:  None
  *
  * Returns:     Nothing
  *
  ***********************************************************************/
-void UninvertRPC(struct RPC_params *p)
+void
+UninvertRPC(struct RPC_params *p)
 {
 	int 	j;
 
@@ -790,11 +892,11 @@ void UninvertRPC(struct RPC_params *p)
 			    && (p->param[j].size == 2)) {
 				int *s = c;
 
-				*s = htons((short) *s) >> 8;
+				*s = htons(*s) >> 8;
 			} else if (p->param[j].size == 2) {
 				int *s = c;
 
-				*s = htons((short) *s);
+				*s = htons(*s);
 			} else {
 				long *l = c;
 
@@ -804,18 +906,20 @@ void UninvertRPC(struct RPC_params *p)
 	}
 }
 
+
 /***********************************************************************
  *
  * Function:    InvertRPC
  *
- * Summary:     
+ * Summary:
  *
  * Parameters:  None
  *
  * Returns:     Nothing
  *
  ***********************************************************************/
-void InvertRPC(struct RPC_params *p)
+void
+InvertRPC(struct RPC_params *p)
 {
 	int 	j;
 
@@ -835,12 +939,13 @@ void InvertRPC(struct RPC_params *p)
 			} else {
 				long *l = c;
 
-				*l = ntohl(*l);
+				*l = ntohl((unsigned) *l);
 			}
 		}
 	}
 }
 
+
 /***********************************************************************
  *
  * Function:    DoRPC
@@ -852,7 +957,8 @@ void InvertRPC(struct RPC_params *p)
  * Returns:     Nothing
  *
  ***********************************************************************/
-unsigned long DoRPC(int sd, int socket, struct RPC_params *p, int *error)
+unsigned long
+DoRPC(int sd, int sockaddr, struct RPC_params *p, int *error)
 {
 	int 	err;
 	long 	D0 = 0,
@@ -861,7 +967,7 @@ unsigned long DoRPC(int sd, int socket, struct RPC_params *p, int *error)
 	InvertRPC(p);
 
 	err =
-	    sys_RPC(sd, socket, p->trap, &D0, &A0, p->args, &p->param[0],
+	    sys_RPC(sd, sockaddr, p->trap, &D0, &A0, p->args, &p->param[0],
 		    p->reply);
 
 	UninvertRPC(p);
@@ -877,55 +983,45 @@ unsigned long DoRPC(int sd, int socket, struct RPC_params *p, int *error)
 		return err;
 }
 
+
 /***********************************************************************
  *
  * Function:    RPC_Int_Void
  *
- * Summary:     
+ * Summary:
  *
  * Parameters:  None
  *
  * Returns:     Nothing
  *
  ***********************************************************************/
-int RPC_Int_Void(int sd, int trap)
+int
+RPC_Int_Void(int sd, int trap)
 {
 	return RPC(sd, 1, trap, 0, RPC_End);
 }
 
+
 /***********************************************************************
  *
  * Function:    RPC_Ptr_Void
  *
- * Summary:     
+ * Summary:
  *
  * Parameters:  None
  *
  * Returns:     Nothing
  *
  ***********************************************************************/
-int RPC_Ptr_Void(int sd, int trap)
+int
+RPC_Ptr_Void(int sd, int trap)
 {
 	return RPC(sd, 1, trap, 1, RPC_End);
 }
 
-/***********************************************************************
- *
- * Function:    RPC_MemCardInfo
- *
- * Summary:     Untested complex RPC example
- *
- * Parameters:  None
- *
- * Returns:     Nothing
- *
- ***********************************************************************/
-int RPC_MemCardInfo(int sd, int cardno, char * cardname, char * manufname,
-                    int * version, long * date, long * romsize, long * ramsize,
-                    long * freeram) {
-  return RPC(sd, 1, 0xA004, 0, RPC_Short(cardno), RPC_Ptr(cardname, 32), 
-                               RPC_Ptr(manufname, 32), RPC_ShortPtr(version),
-                               RPC_LongPtr(date), RPC_LongPtr(romsize),
-                               RPC_LongPtr(ramsize), RPC_LongPtr(freeram));
-}                    
 
+/* vi: set ts=8 sw=4 sts=4 noexpandtab: cin */
+/* Local Variables: */
+/* indent-tabs-mode: t */
+/* c-basic-offset: 8 */
+/* End: */
